==> qmapshack_1.15.0.orig.tar.gz: qmapshack-V_1.15.0/.github/ISSUE_TEMPLATE/everything-that-s-not-a-bug.md <==
---
name: Everything that's not a bug
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

**Important Notice:**

**Do not delete any of the sections. Answer them. If you really**
**think they do not apply to you give a short statement. Feature**
**requests that are not properly filed might be closed without**
**further notice.**

**Choose a good title**

What is a good title?
The title will be listed in the changelog when the issue is fixed. Do
you think someone else would understand what's fixed or done from your
title? Does it really name the real topic of the issue?

[ ] Did you choose a good title?

**Is your feature request related to a problem? Please describe.**

A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**

A clear and concise description of what you want to happen.

**Describe alternatives you've considered**

A clear and concise description of any alternative solutions or features you've considered.

**Give a reason why someone else should spend time on that request**

Keep in mind that you ask others to spend their spare time for your request. Convince them
by giving a reason why solving your request has a benefit for them, too. Good reasons are
if you are able to prove

* The request solves a fundamental problem for everyone
* The request is of general interest for many users

Bad reasons are:
* Because software xyz does it
* Because you just want it to have that way
* Because it will solve a very particular problem.

**Additional context**

Add any other context or screenshots about the feature request here.

==> qmapshack_1.15.2.orig.tar.gz: qmapshack-V_1.15.2/.github/ISSUE_TEMPLATE/everything-that-s-not-a-bug.md <==
---
name: Everything that's not a bug
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

**Important Notice:**

**Do not delete any of the sections. Read what is requested.**
**_Replace(!)_ the instructions by your _answer(!)_. Feature requests**
**reports that are not properly filed might be closed without**
**further notice.**

**Choose a good title**

What is a good title?
The title will be listed in the changelog when the issue is fixed. Do
you think someone else would understand what's fixed or done from your
title? Does it really name the real topic of the issue?

[ ] Did you choose a good title?

**Is your feature request related to a problem? Please describe.**

A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**

A clear and concise description of what you want to happen.

**Describe alternatives you've considered**

A clear and concise description of any alternative solutions or features you've considered.

**Give a reason why someone else should spend time on that request**

Keep in mind that you ask others to spend their spare time for your request. Convince them
by giving a reason why solving your request has a benefit for them, too. Good reasons are
if you are able to prove

* The request solves a fundamental problem for everyone
* The request is of general interest for many users

Bad reasons are:
* Because software xyz does it
* Because you just want it to have that way
* Because it will solve a very particular problem.

**Additional context**

Add any other context or screenshots about the feature request here.
